@@ -66,6 +66,12 @@ class Storage:
     string2contract = {}
 
 
+def _cacheable(string, c):
+    # XXX need a more general way of indicating
+    #     whether a contract is safely cacheable
+    return '$' not in string
+
+
 def parse_contract_string(string):
     assert isinstance(string, str), type(string)
     if string in Storage.string2contract:
@@ -74,7 +80,8 @@ def parse_contract_string(string):
         c = contract_expression.parseString(string,
                                             parseAll=True)[0]
         assert isinstance(c, Contract), 'Want Contract, not %r' % c
-        Storage.string2contract[string] = c
+        if _cacheable(string, c):
+            Storage.string2contract[string] = c
         return c
     except ParseException as e:
         where = Where(string, line=e.lineno, column=e.col)
@@ -596,15 +603,13 @@ def new_contract_impl(identifier, condition):
     # Lastly, it should be a callable
     elif hasattr(condition, '__call__'):
         # Check that the signature is right
-        if can_accept_self_plus_one_argument(condition):
+        if can_accept_self(condition):
             bare_contract = CheckCallableWithSelf(condition)
-        else:
-            can, error = can_accept_exactly_one_argument(condition)
-            if not can:
-                msg = ('The given callable %r should be able to accept '
-                       'exactly one argument. Error: %s ' % (condition, error))
-                raise ValueError(msg)
+        elif can_accept_at_least_one_argument(condition):
             bare_contract = CheckCallable(condition)
+        else:
+            raise ValueError("The given callable %r should be able to accept "
+                             "at least one argument" % condition)
     else:
         raise ValueError('I need either a string or a callable for the '
                          'condition; found %s.' % describe_value(condition))
@@ -685,6 +690,42 @@ def can_accept_exactly_one_argument(callable_thing):
         return True, None
 
 
+def can_accept_at_least_one_argument(callable_thing):
+    """ Checks that a callable can accept at least one argument
+        using introspection.
+    """
+    if inspect.ismethod(callable_thing):  # bound method
+        f = callable_thing.__func__
+        args = (callable_thing.__self__, 'test',)
+    else:
+        if not inspect.isfunction(callable_thing):
+            f = callable_thing.__call__
+        else:
+            f = callable_thing
+        args = ('test',)
+
+    spec = getfullargspec(f)
+    return len(spec.args) > 0 or spec.varargs
+
+
+def can_accept_self(callable_thing):
+    """ Checks that a callable's first argument is self
+    """
+    if inspect.ismethod(callable_thing):  # bound method
+        f = callable_thing.__func__
+    else:
+        if not inspect.isfunction(callable_thing):
+            f = callable_thing.__call__
+        else:
+            f = callable_thing
+
+    spec = getfullargspec(f)
+    if len(spec.args) == 0 or spec.args[0] != 'self':
+        return False
+
+    return True
+
+
 def can_accept_self_plus_one_argument(callable_thing):
     """ Checks that a callable can accept exactly self plus one argument
         using introspection.
