@@ -13,7 +13,7 @@ from pyparsing import (delimitedList, Forward, Literal,
                        MatchFirst, Keyword, Group, White, lineno, col)
 
 
-from .pyparsing_utils import myOperatorPrecedence
+# from .pyparsing_utils import myOperatorPrecedence
 
 
 # Enable memoization (much faster!)
@@ -85,17 +85,20 @@ simple_contract.setName('simple_contract')
 # Import all expressions -- they will call add_contract()
 from .library import (EqualTo, Unary, Binary, composite_contract,
                       identifier_contract, misc_variables_contract,
+                      scoped_variables_ref,
                       int_variables_contract, int_variables_ref,
                       misc_variables_ref, SimpleRValue)
 
 
 number = pi | floatnumber | integer
-operand = number | int_variables_ref | misc_variables_ref
+operand = number | int_variables_ref | misc_variables_ref | scoped_variables_ref
 operand.setName('r-value')
 
-
-rvalue << myOperatorPrecedence(operand, [
-             ('-', 1, opAssoc.RIGHT, Unary.parse_action),
+ 
+op = operatorPrecedence
+# op  = myOperatorPrecedence
+rvalue << op(operand, [
+            ('-', 1, opAssoc.RIGHT, Unary.parse_action),
              ('*', 2, opAssoc.LEFT, Binary.parse_action),
              ('-', 2, opAssoc.LEFT, Binary.parse_action),
              ('+', 2, opAssoc.LEFT, Binary.parse_action),
